/* *****************************************************************
   Directory: /home/mchernoff/P219C_Mito/sas_programs
   Pgm: mwg2_score_meth.sas
   Source: mwg2_score.sas (Oct 17, 2006)
   Date: July 13, 2011
   Last edited:  

   Purpose: 
            * MWG iDACS 616 - Pooling results from Q1 and Q2

            * Inputs data from scoring algorithms 
               - find_date_q1_meth/q2_meth.sas 


   Input files:
                mitometh.master

                mitometh.date_fq2 - MDC scoring
                mitometh.date_fq1 - EPF scoring


   Output files: gr2_score.lst

   Notes:  

*********************************************************************/

* automatic if in same directory *;

options ls=130 ps=50;
run;

/**************************************************/
/* formats */
/**************************************************/

%include "/home/mchernoff/P219C_Mito/methods/mito_tmpformat_meth.sas";

*------------------------------------------*
* Bring in DATA    *
*------------------------------------------*;

x "gunzip /home/mchernoff/P219C_Mito/methods/master.sas7bdat.gz";

proc sort data=mitometh.master out=master (keep=patid /*raceth sex*/);
by patid;
run;

x "gzip /home/mchernoff/P219C_Mito/methods/master.sas7bdat";

%macro prepdat (
     data1= /* Q1 dataset */,
     data2= /* Q2 dataset */
     );

x "gunzip /home/mchernoff/P219C_Mito/methods/&data1..sas7bdat.gz";

proc sort data=mitometh.&data1 out=q1dat 
   (keep=patid /*birthdt*/ sortdt major minor fmindate sortdt 
    rename=(sortdt=casedt fmindate=mindate));
by patid;
run;

x "gzip /home/mchernoff/P219C_Mito/methods/&data1..sas7bdat";

x "gunzip /home/mchernoff/P219C_Mito/methods/&data2..sas7bdat.gz";

proc sort data=mitometh.&data2 out=q2dat(
     keep=patid /*birthdt*/ maxdate mindate total
     rename=(total=totpoint maxdate=casedt));
by patid;
run;


x "gzip /home/mchernoff/P219C_Mito/methods/&data2..sas7bdat";
%mend;


*--------------------------------------*;
* summary *;
*--------------------------------------*;

%prepdat (data1=date_fq1, data2=date_fq2);

proc format;
 value yn10f
  1="Yes"
  0="No"
  ;
run;
 
data all;
merge q1dat (keep=patid major minor)
      q2dat (keep=patid totpoint)
      master (in=in1);
by patid;
if in1;
if major=1 or minor=1 then q1point=1;
 else q1point=0;
if totpoint > 1 then q2pnt2=1;
 else q2pnt2=0;
label q1point="EPF criterion met"
      q2pnt2="MDC criterion met"
      ;
run;


options center orientation=portrait ls=80 ps=55;

proc printto print="/home/mchernoff/P219C_Mito/methods/gr2_score.lst" new;

proc freq data=all;
tables q1point*minor*major/list missprint;
tables q2pnt2*totpoint/list missprint;
tables q1point*q2pnt2/ norow nocol missprint agree;
format q2pnt2 q1point yn10f.;
run;

proc printto print=print;

endsas;











